@@ -673,7 +673,7 @@ photos_base_item_thumbnail_path_info (GObject *source_object, GAsyncResult *res,
   PhotosBaseItemPrivate *priv = self->priv;
   GError *error = NULL;
   GFile *file = G_FILE (source_object);
-  GFileInfo *info;
+  GFileInfo *info = NULL;
 
   info = g_file_query_info_finish (file, res, &error);
   if (error != NULL)
@@ -697,6 +697,7 @@ photos_base_item_thumbnail_path_info (GObject *source_object, GAsyncResult *res,
     }
 
  out:
+  g_clear_object (&info);
   g_object_unref (self);
 }
 
@@ -740,7 +741,7 @@ photos_base_item_file_query_info (GObject *source_object, GAsyncResult *res, gpo
   PhotosBaseItemPrivate *priv = self->priv;
   GError *error = NULL;
   GFile *file = G_FILE (source_object);
-  GFileInfo *info;
+  GFileInfo *info = NULL;
 
   info = g_file_query_info_finish (file, res, &error);
   if (error != NULL)
@@ -764,6 +765,7 @@ photos_base_item_file_query_info (GObject *source_object, GAsyncResult *res, gpo
     }
 
  out:
+  g_clear_object (&info);
   g_object_unref (self);
 }
 
