@@ -195,7 +195,9 @@ gboolean            photos_base_item_operation_get           (PhotosBaseItem *se
                                                               const gchar *first_property_name,
                                                               ...) G_GNUC_NULL_TERMINATED G_GNUC_WARN_UNUSED_RESULT;
 
-gboolean            photos_base_item_operation_undo          (PhotosBaseItem *self);
+gboolean            photos_base_item_operation_remove        (PhotosBaseItem *self, const gchar *operation);
+
+void                photos_base_item_operations_revert       (PhotosBaseItem *self);
 
 void                photos_base_item_pipeline_save_async     (PhotosBaseItem *self,
                                                               GCancellable *cancellable,
@@ -206,6 +208,8 @@ gboolean            photos_base_item_pipeline_save_finish    (PhotosBaseItem *se
                                                               GAsyncResult *res,
                                                               GError **error);
 
+void                photos_base_item_pipeline_snapshot       (PhotosBaseItem *self);
+
 void                photos_base_item_print                   (PhotosBaseItem *self, GtkWidget *toplevel);
 
 void                photos_base_item_process_async           (PhotosBaseItem *self,
@@ -226,9 +230,9 @@ void                photos_base_item_save_async              (PhotosBaseItem *se
                                                               GAsyncReadyCallback callback,
                                                               gpointer user_data);
 
-gboolean            photos_base_item_save_finish             (PhotosBaseItem *self,
+GFile              *photos_base_item_save_finish             (PhotosBaseItem *self,
                                                               GAsyncResult *res,
-                                                              GError **error);
+                                                              GError **error) G_GNUC_WARN_UNUSED_RESULT;
 
 void                photos_base_item_save_guess_sizes_async  (PhotosBaseItem *self,
                                                               GCancellable *cancellable,
