@@ -1,6 +1,6 @@
 /*
  * Photos - access, organize and share your photos on GNOME
- * Copyright © 2012, 2013, 2014 Red Hat, Inc.
+ * Copyright © 2012 – 2016 Red Hat, Inc.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -81,9 +81,6 @@ gboolean               photos_main_toolbar_is_focus               (PhotosMainToo
 
 void                   photos_main_toolbar_reset_toolbar_mode     (PhotosMainToolbar *self);
 
-void                   photos_main_toolbar_set_cancellable        (PhotosMainToolbar *self,
-                                                                   GCancellable *cancellable);
-
 void                   photos_main_toolbar_set_stack              (PhotosMainToolbar *self, GtkStack *stack);
 
 void                   photos_main_toolbar_set_view_model         (PhotosMainToolbar *self, PhotosViewModel *model);
