@@ -1,6 +1,6 @@
 /*
  * Photos - access, organize and share your photos on GNOME
- * Copyright © 2013, 2014, 2015 Red Hat, Inc.
+ * Copyright © 2013 – 2016 Red Hat, Inc.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -31,18 +31,23 @@
 #include "photos-utils.h"
 
 
-struct _PhotosTrackerCollectionsControllerPrivate
+struct _PhotosTrackerCollectionsController
 {
+  PhotosTrackerController parent_instance;
   PhotosBaseManager *item_mngr;
   PhotosModeController *mode_cntrlr;
   PhotosOffsetController *offset_cntrlr;
 };
 
+struct _PhotosTrackerCollectionsControllerClass
+{
+  PhotosTrackerControllerClass parent_class;
+};
+
 
 G_DEFINE_TYPE_WITH_CODE (PhotosTrackerCollectionsController,
                          photos_tracker_collections_controller,
                          PHOTOS_TYPE_TRACKER_CONTROLLER,
-                         G_ADD_PRIVATE (PhotosTrackerCollectionsController)
                          photos_utils_ensure_extension_points ();
                          g_io_extension_point_implement (PHOTOS_TRACKER_CONTROLLER_EXTENSION_POINT_NAME,
                                                          g_define_type_id,
@@ -53,12 +58,11 @@ G_DEFINE_TYPE_WITH_CODE (PhotosTrackerCollectionsController,
 static void
 photos_tracker_collections_controller_col_active_changed (PhotosTrackerCollectionsController *self)
 {
-  PhotosTrackerCollectionsControllerPrivate *priv = self->priv;
   PhotosWindowMode mode;
 
-  g_return_if_fail (priv->mode_cntrlr != NULL);
+  g_return_if_fail (self->mode_cntrlr != NULL);
 
-  mode = photos_mode_controller_get_window_mode (priv->mode_cntrlr);
+  mode = photos_mode_controller_get_window_mode (self->mode_cntrlr);
   if (mode != PHOTOS_WINDOW_MODE_COLLECTIONS)
     return;
 
@@ -70,7 +74,7 @@ static PhotosOffsetController *
 photos_tracker_collections_controller_get_offset_controller (PhotosTrackerController *trk_cntrlr)
 {
   PhotosTrackerCollectionsController *self = PHOTOS_TRACKER_COLLECTIONS_CONTROLLER (trk_cntrlr);
-  return g_object_ref (self->priv->offset_cntrlr);
+  return g_object_ref (self->offset_cntrlr);
 }
 
 
@@ -78,15 +82,14 @@ static PhotosQuery *
 photos_tracker_collections_controller_get_query (PhotosTrackerController *trk_cntrlr)
 {
   PhotosTrackerCollectionsController *self = PHOTOS_TRACKER_COLLECTIONS_CONTROLLER (trk_cntrlr);
-  PhotosTrackerCollectionsControllerPrivate *priv = self->priv;
   GApplication *app;
   PhotosBaseItem *collection;
   PhotosSearchContextState *state;
   gint flags;
 
-  g_return_val_if_fail (priv->item_mngr != NULL, NULL);
+  g_return_val_if_fail (self->item_mngr != NULL, NULL);
 
-  collection = photos_item_manager_get_active_collection (PHOTOS_ITEM_MANAGER (priv->item_mngr));
+  collection = photos_item_manager_get_active_collection (PHOTOS_ITEM_MANAGER (self->item_mngr));
   if (collection != NULL)
     flags = PHOTOS_QUERY_FLAGS_NONE;
   else
@@ -95,7 +98,7 @@ photos_tracker_collections_controller_get_query (PhotosTrackerController *trk_cn
   app = g_application_get_default ();
   state = photos_search_context_get_state (PHOTOS_SEARCH_CONTEXT (app));
 
-  return photos_query_builder_global_query (state, flags, priv->offset_cntrlr);
+  return photos_query_builder_global_query (state, flags, self->offset_cntrlr);
 }
 
 
@@ -124,7 +127,7 @@ photos_tracker_collections_controller_dispose (GObject *object)
 {
   PhotosTrackerCollectionsController *self = PHOTOS_TRACKER_COLLECTIONS_CONTROLLER (object);
 
-  g_clear_object (&self->priv->offset_cntrlr);
+  g_clear_object (&self->offset_cntrlr);
 
   G_OBJECT_CLASS (photos_tracker_collections_controller_parent_class)->dispose (object);
 }
@@ -134,13 +137,12 @@ static void
 photos_tracker_collections_controller_finalize (GObject *object)
 {
   PhotosTrackerCollectionsController *self = PHOTOS_TRACKER_COLLECTIONS_CONTROLLER (object);
-  PhotosTrackerCollectionsControllerPrivate *priv = self->priv;
 
-  if (priv->item_mngr != NULL)
-    g_object_remove_weak_pointer (G_OBJECT (priv->item_mngr), (gpointer *) &priv->item_mngr);
+  if (self->item_mngr != NULL)
+    g_object_remove_weak_pointer (G_OBJECT (self->item_mngr), (gpointer *) &self->item_mngr);
 
-  if (priv->mode_cntrlr != NULL)
-    g_object_remove_weak_pointer (G_OBJECT (priv->mode_cntrlr), (gpointer *) &priv->mode_cntrlr);
+  if (self->mode_cntrlr != NULL)
+    g_object_remove_weak_pointer (G_OBJECT (self->mode_cntrlr), (gpointer *) &self->mode_cntrlr);
 
   G_OBJECT_CLASS (photos_tracker_collections_controller_parent_class)->finalize (object);
 }
@@ -149,27 +151,23 @@ photos_tracker_collections_controller_finalize (GObject *object)
 static void
 photos_tracker_collections_controller_init (PhotosTrackerCollectionsController *self)
 {
-  PhotosTrackerCollectionsControllerPrivate *priv;
   GApplication *app;
   PhotosSearchContextState *state;
 
-  self->priv = photos_tracker_collections_controller_get_instance_private (self);
-  priv = self->priv;
-
   app = g_application_get_default ();
   state = photos_search_context_get_state (PHOTOS_SEARCH_CONTEXT (app));
 
-  priv->item_mngr = state->item_mngr;
-  g_object_add_weak_pointer (G_OBJECT (priv->item_mngr), (gpointer *) &priv->item_mngr);
-  g_signal_connect_swapped (priv->item_mngr,
+  self->item_mngr = state->item_mngr;
+  g_object_add_weak_pointer (G_OBJECT (self->item_mngr), (gpointer *) &self->item_mngr);
+  g_signal_connect_swapped (self->item_mngr,
                             "active-collection-changed",
                             G_CALLBACK (photos_tracker_collections_controller_col_active_changed),
                             self);
 
-  priv->mode_cntrlr = state->mode_cntrlr;
-  g_object_add_weak_pointer (G_OBJECT (priv->mode_cntrlr), (gpointer *) &priv->mode_cntrlr);
+  self->mode_cntrlr = state->mode_cntrlr;
+  g_object_add_weak_pointer (G_OBJECT (self->mode_cntrlr), (gpointer *) &self->mode_cntrlr);
 
-  priv->offset_cntrlr = photos_offset_collections_controller_dup_singleton ();
+  self->offset_cntrlr = photos_offset_collections_controller_dup_singleton ();
 }
 
 
